@@ -1,9 +1,7 @@
 # defaults
 ###########
 guiToolkit.default <- 'RGtk2'
-tfr.wpp.year.default <- 2010
-e0.wpp.year.default <- 2010
-pop.wpp.year.default <- 2010
+wpp.year.default <- 2010
 
 # color.main <- "blanchedalmond"
 # color.button <- "bisque1"
